using Attribute;
using Model;
using Model.Base;
using Repository;
using Service;
using Microsoft.AspNetCore.Mvc;
using Vo.Admin;


namespace Services
{
    /// <summary>
    /// 好哒终端商户绑定记录Service业务层处理
    /// </summary>
    [AppService(ServiceType = typeof(IHdBindRecordService), ServiceLifetime = LifeTime.Transient)]
    public class HdBindRecordService : BaseService<HdBindRecord>, IHdBindRecordService
    {
        /// <summary>
        /// 好哒终端商户绑定记录-列表
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <param name="page">分页参数</param>
        /// <returns>列表</returns>
        public PagedInfo<GetHdBindRecordListVo> getHdBindRecordList([FromQuery] PagerInfo page, [FromQuery] HdBindRecord param)
        {
            //拼装查询条件
            var predicate = Expressionable.Create<HdBindRecord>();
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.snNo), m => m.snNo.Contains(param.snNo));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.mchtNo), m => m.mchtNo.Contains(param.mchtNo));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.deviceType), m => m.deviceType.Contains(param.deviceType));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.bindTime), m => m.bindTime.Contains(param.bindTime));
            var response = Queryable()
                .Where(predicate.ToExpression())
                .SplitTable(DateTime.Now.AddMonths(-3), DateTime.Now)
                .OrderByDescending(m => m.id)
                .ToPage<HdBindRecord, GetHdBindRecordListVo>(page);
            return response;
        }


        /// <summary>
        /// 好哒终端商户绑定记录-详情
        /// </summary>
        /// <param name="id">ID</param>
        /// <returns>详情</returns>
        public HdBindRecord getHdBindRecordQuery(long id)
        {
            //拼装查询条件
            var predicate = Expressionable.Create<HdBindRecord>();
            predicate = predicate.AndIF(id > 0, m => m.id == id);
            var response = Queryable()
                .Where(predicate.ToExpression())
                .SplitTable(DateTime.Now.AddMonths(-3), DateTime.Now)
                .First();
            return response;
        }


        /// <summary>
        /// 好哒终端商户绑定记录-添加
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <returns>添加</returns>
        public long addHdBindRecord([FromBody] HdBindRecord param)
        {
            return Insertable(param).SplitTable().ExecuteReturnSnowflakeId();
        }


        /// <summary>
        /// 好哒终端商户绑定记录-修改
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <returns>修改</returns>
        public long updateHdBindRecord([FromBody] HdBindRecord param)
        {
            return Context.Updateable(param).SplitTable().ExecuteCommand();
        }


        /// <summary>
        /// 好哒终端商户绑定记录-删除
        /// </summary>
        /// <param name="id">ID</param>
        /// <returns>删除</returns>
        public long deleteHdBindRecord(int id)
        {
            return Context.Deleteable<HdBindRecord>(id).SplitTable().ExecuteCommand();
        }



    }
}
