using Attribute;
using Model;
using Model.Base;
using Repository;
using Service;
using Microsoft.AspNetCore.Mvc;
using Vo.Admin;


namespace Services
{
    /// <summary>
    /// 好哒押金记录Service业务层处理
    /// </summary>
    [AppService(ServiceType = typeof(IHdDepositRecordService), ServiceLifetime = LifeTime.Transient)]
    public class HdDepositRecordService : BaseService<HdDepositRecord>, IHdDepositRecordService
    {
        /// <summary>
        /// 好哒押金记录-列表
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <param name="page">分页参数</param>
        /// <returns>列表</returns>
        public PagedInfo<GetHdDepositRecordListVo> getHdDepositRecordList([FromQuery] PagerInfo page, [FromQuery] HdDepositRecord param)
        {
            //拼装查询条件
            var predicate = Expressionable.Create<HdDepositRecord>();
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.effectiveTime), m => m.effectiveTime.Contains(param.effectiveTime));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.deviceType), m => m.deviceType.Contains(param.deviceType));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.channelKind), m => m.channelKind.Contains(param.channelKind));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.snNo), m => m.snNo.Contains(param.snNo));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.depositAmount), m => m.depositAmount.Contains(param.depositAmount));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.activityId), m => m.activityId.Contains(param.activityId));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.mchtNm), m => m.mchtNm.Contains(param.mchtNm));
            predicate = predicate.AndIF(!string.IsNullOrEmpty(param.mchtNo), m => m.mchtNo.Contains(param.mchtNo));
            var response = Queryable()
                .Where(predicate.ToExpression())
                .SplitTable(DateTime.Now.AddMonths(-3), DateTime.Now)
                .OrderByDescending(m => m.id)
                .ToPage<HdDepositRecord, GetHdDepositRecordListVo>(page);
            return response;
        }


        /// <summary>
        /// 好哒押金记录-详情
        /// </summary>
        /// <param name="id">ID</param>
        /// <returns>详情</returns>
        public HdDepositRecord getHdDepositRecordQuery(long id)
        {
            //拼装查询条件
            var predicate = Expressionable.Create<HdDepositRecord>();
            predicate = predicate.AndIF(id > 0, m => m.id == id);
            var response = Queryable()
                .Where(predicate.ToExpression())
                .SplitTable(DateTime.Now.AddMonths(-3), DateTime.Now)
                .First();
            return response;
        }


        /// <summary>
        /// 好哒押金记录-添加
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <returns>添加</returns>
        public long addHdDepositRecord([FromBody] HdDepositRecord param)
        {
            return Insertable(param).SplitTable().ExecuteReturnSnowflakeId();
        }


        /// <summary>
        /// 好哒押金记录-修改
        /// </summary>
        /// <param name="param">参数请求体</param>
        /// <returns>修改</returns>
        public long updateHdDepositRecord([FromBody] HdDepositRecord param)
        {
            return Context.Updateable(param).SplitTable().ExecuteCommand();
        }


        /// <summary>
        /// 好哒押金记录-删除
        /// </summary>
        /// <param name="id">ID</param>
        /// <returns>删除</returns>
        public long deleteHdDepositRecord(long id)
        {
            return Context.Deleteable<HdDepositRecord>(id).SplitTable().ExecuteCommand();
        }



    }
}
